<div id="carousel-work" class="carousel carousel-work fade" data-ride="carousel">
  <!-- Wrapper for slides -->
  <div class="carousel-inner" role="listbox">
	{% for image in object.images.all %}
    <div class="item{% if forloop.first %} active{% endif %}">
      <img src="{{ image.image.url }}" alt="{{ image.alt }}" class="img-responsive">
      <div class="carousel-caption">
        <h3>{{ image.title }}</h3>
        <p class="list-group-item-text">
          {{ image.description }}
        </p>
      </div>
    </div>
	{% endfor %}
  </div>
  <!-- Controls -->
  <p class="carousel-control-work">
    <a class="" href="#carousel-work" role="button" data-slide="prev">
      <span class="icon-left-open-big" aria-hidden="true"></span>
      <span class="sr-only">Previous</span>
    </a>
    <a class="" href="#carousel-work" role="button" data-slide="next">
      <span class="icon-right-open-big" aria-hidden="true"></span>
      <span class="sr-only">Next</span>
    </a>
  </p>
</div><!-- carousel -->
